import { VideoAbuseModel } from '../../../models/abuse/video-abuse';
import { VideoCommentAbuseModel } from '../../../models/abuse/video-comment-abuse';
import { ApplicationModel } from '../../../models/application/application';
import { PluginModel } from '../../../models/server/plugin';
import { UserNotificationModel } from '../../../models/user/user-notification';
import { PickWith, PickWithOpt } from '../../../../shared/typescript-utils';
import { AbuseModel } from '../../../models/abuse/abuse';
import { AccountModel } from '../../../models/account/account';
import { ActorModel } from '../../../models/actor/actor';
import { ActorFollowModel } from '../../../models/actor/actor-follow';
import { ActorImageModel } from '../../../models/actor/actor-image';
import { ServerModel } from '../../../models/server/server';
import { VideoModel } from '../../../models/video/video';
import { VideoBlacklistModel } from '../../../models/video/video-blacklist';
import { VideoChannelModel } from '../../../models/video/video-channel';
import { VideoCommentModel } from '../../../models/video/video-comment';
import { VideoImportModel } from '../../../models/video/video-import';
declare type Use<K extends keyof UserNotificationModel, M> = PickWith<UserNotificationModel, K, M>;
export declare module UserNotificationIncludes {
    type ActorImageInclude = Pick<ActorImageModel, 'createdAt' | 'filename' | 'getStaticPath' | 'width' | 'updatedAt'>;
    type VideoInclude = Pick<VideoModel, 'id' | 'uuid' | 'name'>;
    type VideoIncludeChannel = VideoInclude & PickWith<VideoModel, 'VideoChannel', VideoChannelIncludeActor>;
    type ActorInclude = Pick<ActorModel, 'preferredUsername' | 'getHost'> & PickWith<ActorModel, 'Avatars', ActorImageInclude[]> & PickWith<ActorModel, 'Server', Pick<ServerModel, 'host'>>;
    type VideoChannelInclude = Pick<VideoChannelModel, 'id' | 'name' | 'getDisplayName'>;
    type VideoChannelIncludeActor = VideoChannelInclude & PickWith<VideoChannelModel, 'Actor', ActorInclude>;
    type AccountInclude = Pick<AccountModel, 'id' | 'name' | 'getDisplayName'>;
    type AccountIncludeActor = AccountInclude & PickWith<AccountModel, 'Actor', ActorInclude>;
    type VideoCommentInclude = Pick<VideoCommentModel, 'id' | 'originCommentId' | 'getThreadId'> & PickWith<VideoCommentModel, 'Account', AccountIncludeActor> & PickWith<VideoCommentModel, 'Video', VideoInclude>;
    type VideoAbuseInclude = Pick<VideoAbuseModel, 'id'> & PickWith<VideoAbuseModel, 'Video', VideoInclude>;
    type VideoCommentAbuseInclude = Pick<VideoCommentAbuseModel, 'id'> & PickWith<VideoCommentAbuseModel, 'VideoComment', Pick<VideoCommentModel, 'id' | 'originCommentId' | 'getThreadId'> & PickWith<VideoCommentModel, 'Video', Pick<VideoModel, 'id' | 'name' | 'uuid'>>>;
    type AbuseInclude = Pick<AbuseModel, 'id' | 'state'> & PickWith<AbuseModel, 'VideoAbuse', VideoAbuseInclude> & PickWith<AbuseModel, 'VideoCommentAbuse', VideoCommentAbuseInclude> & PickWith<AbuseModel, 'FlaggedAccount', AccountIncludeActor>;
    type VideoBlacklistInclude = Pick<VideoBlacklistModel, 'id'> & PickWith<VideoAbuseModel, 'Video', VideoInclude>;
    type VideoImportInclude = Pick<VideoImportModel, 'id' | 'magnetUri' | 'targetUrl' | 'torrentName'> & PickWith<VideoImportModel, 'Video', VideoInclude>;
    type ActorFollower = Pick<ActorModel, 'preferredUsername' | 'getHost'> & PickWith<ActorModel, 'Account', AccountInclude> & PickWith<ActorModel, 'Server', Pick<ServerModel, 'host'>> & PickWithOpt<ActorModel, 'Avatars', ActorImageInclude[]>;
    type ActorFollowing = Pick<ActorModel, 'preferredUsername' | 'type' | 'getHost'> & PickWith<ActorModel, 'VideoChannel', VideoChannelInclude> & PickWith<ActorModel, 'Account', AccountInclude> & PickWith<ActorModel, 'Server', Pick<ServerModel, 'host'>>;
    type ActorFollowInclude = Pick<ActorFollowModel, 'id' | 'state'> & PickWith<ActorFollowModel, 'ActorFollower', ActorFollower> & PickWith<ActorFollowModel, 'ActorFollowing', ActorFollowing>;
    type PluginInclude = Pick<PluginModel, 'id' | 'name' | 'type' | 'latestVersion'>;
    type ApplicationInclude = Pick<ApplicationModel, 'latestPeerTubeVersion'>;
}
export declare type MUserNotification = Omit<UserNotificationModel, 'User' | 'Video' | 'VideoComment' | 'Abuse' | 'VideoBlacklist' | 'VideoImport' | 'Account' | 'ActorFollow' | 'Plugin' | 'Application'>;
export declare type UserNotificationModelForApi = MUserNotification & Use<'Video', UserNotificationIncludes.VideoIncludeChannel> & Use<'VideoComment', UserNotificationIncludes.VideoCommentInclude> & Use<'Abuse', UserNotificationIncludes.AbuseInclude> & Use<'VideoBlacklist', UserNotificationIncludes.VideoBlacklistInclude> & Use<'VideoImport', UserNotificationIncludes.VideoImportInclude> & Use<'ActorFollow', UserNotificationIncludes.ActorFollowInclude> & Use<'Plugin', UserNotificationIncludes.PluginInclude> & Use<'Application', UserNotificationIncludes.ApplicationInclude> & Use<'Account', UserNotificationIncludes.AccountIncludeActor>;
export {};
//# sourceMappingURL=user-notification.d.ts.map